@@ -25,10 +25,8 @@ from unittest import mock
 import uuid
 import yaml
 
-from oslotest import base as test_base
-import six
-
 from oslo_utils import fileutils
+from oslo_utils.tests import base as test_base
 
 TEST_PERMISSIONS = stat.S_IRWXU
 
@@ -37,11 +35,12 @@ class EnsureTree(test_base.BaseTestCase):
     def test_ensure_tree(self):
         tmpdir = tempfile.mkdtemp()
         try:
-            testdir = '%s/foo/bar/baz' % (tmpdir,)
+            testdir = f'{tmpdir}/foo/bar/baz'
             fileutils.ensure_tree(testdir, TEST_PERMISSIONS)
             self.assertTrue(os.path.isdir(testdir))
-            self.assertEqual(os.stat(testdir).st_mode,
-                             TEST_PERMISSIONS | stat.S_IFDIR)
+            self.assertEqual(
+                os.stat(testdir).st_mode, TEST_PERMISSIONS | stat.S_IFDIR
+            )
         finally:
             if os.path.exists(tmpdir):
                 shutil.rmtree(tmpdir)
@@ -116,8 +115,8 @@ class RemovePathOnError(test_base.BaseTestCase):
 
         try:
             with fileutils.remove_path_on_error(
-                    tmpdir,
-                    lambda path: fileutils.delete_if_exists(path, os.rmdir)):
+                tmpdir, lambda path: fileutils.delete_if_exists(path, os.rmdir)
+            ):
                 raise Exception
         except Exception:
             self.assertFalse(os.path.exists(tmpdir))
@@ -125,13 +124,13 @@ class RemovePathOnError(test_base.BaseTestCase):
 
 class WriteToTempfileTestCase(test_base.BaseTestCase):
     def setUp(self):
-        super(WriteToTempfileTestCase, self).setUp()
-        self.content = 'testing123'.encode('ascii')
+        super().setUp()
+        self.content = b'testing123'
 
     def check_file_content(self, path):
-        with open(path, 'r') as fd:
+        with open(path) as fd:
             ans = fd.read()
-            self.assertEqual(self.content, six.b(ans))
+            self.assertEqual(self.content, ans.encode("latin-1"))
 
     def test_file_without_path_and_suffix(self):
         res = fileutils.write_to_tempfile(self.content)
@@ -145,7 +144,7 @@ class WriteToTempfileTestCase(test_base.BaseTestCase):
 
     def test_file_with_not_existing_path(self):
         random_dir = uuid.uuid4().hex
-        path = '/tmp/%s/test1' % random_dir
+        path = f'/tmp/{random_dir}/test1'
         res = fileutils.write_to_tempfile(self.content, path=path)
         self.assertTrue(os.path.exists(res))
         (basepath, tmpfile) = os.path.split(res)
@@ -170,10 +169,10 @@ class WriteToTempfileTestCase(test_base.BaseTestCase):
     def test_file_with_not_existing_path_and_not_default_suffix(self):
         suffix = '.txt'
         random_dir = uuid.uuid4().hex
-        path = '/tmp/%s/test2' % random_dir
-        res = fileutils.write_to_tempfile(self.content,
-                                          path=path,
-                                          suffix=suffix)
+        path = f'/tmp/{random_dir}/test2'
+        res = fileutils.write_to_tempfile(
+            self.content, path=path, suffix=suffix
+        )
         self.assertTrue(os.path.exists(res))
         (basepath, tmpfile) = os.path.split(res)
         self.assertTrue(tmpfile.startswith('tmp'))
@@ -196,15 +195,14 @@ class WriteToTempfileTestCase(test_base.BaseTestCase):
 
 
 class TestComputeFileChecksum(test_base.BaseTestCase):
-
     def setUp(self):
-        super(TestComputeFileChecksum, self).setUp()
-        self.content = 'fake_content'.encode('ascii')
+        super().setUp()
+        self.content = b'fake_content'
 
     def check_file_content(self, content, path):
-        with open(path, 'r') as fd:
+        with open(path) as fd:
             ans = fd.read()
-            self.assertEqual(content, six.b(ans))
+            self.assertEqual(content, ans.encode("latin-1"))
 
     def test_compute_checksum_default_algorithm(self):
         path = fileutils.write_to_tempfile(self.content)
@@ -228,7 +226,8 @@ class TestComputeFileChecksum(test_base.BaseTestCase):
 
         with mock.patch.object(time, "sleep") as sleep_mock:
             actual_checksum = fileutils.compute_file_checksum(
-                path, read_chunksize=4)
+                path, read_chunksize=4
+            )
 
         sleep_mock.assert_has_calls([mock.call(0)] * 3)
         # Just to make sure that there were exactly 3 calls
@@ -243,8 +242,9 @@ class TestComputeFileChecksum(test_base.BaseTestCase):
         expected_checksum = hashlib.sha512()
         expected_checksum.update(self.content)
 
-        actual_checksum = fileutils.compute_file_checksum(path,
-                                                          algorithm='sha512')
+        actual_checksum = fileutils.compute_file_checksum(
+            path, algorithm='sha512'
+        )
 
         self.assertEqual(expected_checksum.hexdigest(), actual_checksum)
 
@@ -253,8 +253,9 @@ class TestComputeFileChecksum(test_base.BaseTestCase):
         self.assertTrue(os.path.exists(path))
         self.check_file_content(self.content, path)
 
-        self.assertRaises(ValueError, fileutils.compute_file_checksum,
-                          path, algorithm='foo')
+        self.assertRaises(
+            ValueError, fileutils.compute_file_checksum, path, algorithm='foo'
+        )
 
     def test_file_does_not_exist(self):
         random_file_name = uuid.uuid4().hex
@@ -270,7 +271,7 @@ class LastBytesTestCase(test_base.BaseTestCase):
     """Test the last_bytes() utility method."""
 
     def setUp(self):
-        super(LastBytesTestCase, self).setUp()
+        super().setUp()
         self.content = b'1234567890'
 
     def test_truncated(self):
@@ -288,19 +289,17 @@ class LastBytesTestCase(test_base.BaseTestCase):
         self.assertEqual(0, unread_bytes)
 
     def test_non_exist_file(self):
-        self.assertRaises(IOError, fileutils.last_bytes,
-                          'non_exist_file', 1000)
+        self.assertRaises(
+            IOError, fileutils.last_bytes, 'non_exist_file', 1000
+        )
 
 
 class FileTypeTestCase(test_base.BaseTestCase):
     """Test the is_yaml() and is_json() utility methods."""
 
     def setUp(self):
-        super(FileTypeTestCase, self).setUp()
-        data = {
-            'name': 'test',
-            'website': 'example.com'
-        }
+        super().setUp()
+        data = {'name': 'test', 'website': 'example.com'}
         temp_dir = tempfile.mkdtemp()
         self.json_file = tempfile.mktemp(dir=temp_dir)
         self.yaml_file = tempfile.mktemp(dir=temp_dir)
